==> banshee-1-0.98.1.tar.gz: banshee-1-0.98.1/src/Core/Banshee.ThickClient/Banshee.Gui.Widgets/ConnectedVolumeButton.cs <==
//
// ConnectedVolumeButton.cs
//
// Author:
//   Aaron Bockover <abockover@novell.com>
//
// Copyright (C) 2007 Novell, Inc.
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
//
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

using System;

using Banshee.MediaEngine;
using Banshee.ServiceStack;

namespace Banshee.Gui.Widgets
{
    public class ConnectedVolumeButton : Bacon.VolumeButton
    {
        private bool emit_lock = false;
        
        public ConnectedVolumeButton () : base ()
        {
            Volume = PlayerEngineService.VolumeSchema.Get ();
            ServiceManager.PlayerEngine.EventChanged += OnPlayerEngineEventChanged;
        }
        
        private void OnPlayerEngineEventChanged (object o, PlayerEngineEventArgs args)
        {
            if (args.Event == PlayerEngineEvent.Volume) {
                emit_lock = true;
                Volume = ServiceManager.PlayerEngine.Volume;
                emit_lock = false;
            }
        }
        
        protected override void OnVolumeChanged ()
        {
            if (emit_lock) {
                return;
            }
            
            ServiceManager.PlayerEngine.Volume = (ushort)Volume;
            PlayerEngineService.VolumeSchema.Set(Volume);
            
            base.OnVolumeChanged ();
        }
    }
}

==> banshee-1-1.5.6.tar.gz: banshee-1-1.5.6/src/Core/Banshee.ThickClient/Banshee.Gui.Widgets/ConnectedVolumeButton.cs <==
//
// ConnectedVolumeButton.cs
//
// Author:
//   Aaron Bockover <abockover@novell.com>
//
// Copyright (C) 2007 Novell, Inc.
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
//
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

using System;

using Banshee.MediaEngine;
using Banshee.ServiceStack;

namespace Banshee.Gui.Widgets
{
    public class ConnectedVolumeButton : Bacon.VolumeButton
    {
        private bool emit_lock = false;

        public ConnectedVolumeButton () : base()
        {
            emit_lock = true;
            Volume = PlayerEngineService.VolumeSchema.Get ();
            emit_lock = false;
            ServiceManager.PlayerEngine.ConnectEvent (OnPlayerEvent, PlayerEvent.Volume);
        }

        public ConnectedVolumeButton (bool classic) : this ()
        {
            Classic = classic;
        }

        private void OnPlayerEvent (PlayerEventArgs args)
        {
            emit_lock = true;
            Volume = ServiceManager.PlayerEngine.Volume;
            emit_lock = false;
        }

        protected override void OnVolumeChanged ()
        {
            PlayerEngineService.VolumeSchema.Set (Volume);

            if (emit_lock) {
                return;
            }

            ServiceManager.PlayerEngine.Volume = (ushort)Volume;

            base.OnVolumeChanged ();
        }
    }
}
